from unittest import TestCase

from scp.ethyl_alcohol import EthylAlcohol


class TestPropyleneGlycol(TestCase):
    def test_1(self):

        p = EthylAlcohol(0.0)

        # Visc @ T=5degC, X=0: 1.5015e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(5), 1.5015e-03, delta=1.5015e-06)

        # Dens @ T=5degC, X=0: 1.0001e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(5), 1.0001e03, delta=1.0001e00)

        # SpHt @ T=5degC, X=0: 4.2052e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(5), 4.2052e03, delta=4.2052e00)

        # Cond @ T=5degC, X=0: 5.7090e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(5), 5.7090e-01, delta=5.7090e-04)

        # Visc @ T=20degC, X=0: 1.0005e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(20), 1.0005e-03, delta=1.0005e-06)

        # Dens @ T=20degC, X=0: 9.9818e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(20), 9.9818e02, delta=9.9818e-01)

        # SpHt @ T=20degC, X=0: 4.1683e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(20), 4.1683e03, delta=4.1683e00)

        # Cond @ T=20degC, X=0: 5.9802e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(20), 5.9802e-01, delta=5.9802e-04)

        # Visc @ T=40degC, X=0: 6.5457e-04. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(40), 6.5457e-04, delta=6.5457e-07)

        # Dens @ T=40degC, X=0: 9.9244e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(40), 9.9244e02, delta=9.9244e-01)

        # SpHt @ T=40degC, X=0: 4.2005e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(40), 4.2005e03, delta=4.2005e00)

        # Cond @ T=40degC, X=0: 6.3014e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(40), 6.3014e-01, delta=6.3014e-04)

    def test_2(self):

        p = EthylAlcohol(0.2)

        # Visc @ T=5degC, X=0.2: 4.0621e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(5), 4.0621e-03, delta=4.0621e-06)

        # Dens @ T=5degC, X=0.2: 9.7442e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(5), 9.7442e02, delta=9.7442e-01)

        # SpHt @ T=5degC, X=0.2: 4.3595e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(5), 4.3595e03, delta=4.3595e00)

        # Cond @ T=5degC, X=0.2: 4.5243e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(5), 4.5243e-01, delta=4.5243e-04)

        # Visc @ T=20degC, X=0.2: 2.1648e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(20), 2.1648e-03, delta=2.1648e-06)

        # Dens @ T=20degC, X=0.2: 9.6892e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(20), 9.6892e02, delta=9.6892e-01)

        # SpHt @ T=20degC, X=0.2: 4.3287e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(20), 4.3287e03, delta=4.3287e00)

        # Cond @ T=20degC, X=0.2: 4.6631e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(20), 4.6631e-01, delta=4.6631e-04)

        # Visc @ T=40degC, X=0.2: 1.1640e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(40), 1.1640e-03, delta=1.1640e-06)

        # Dens @ T=40degC, X=0.2: 9.5881e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(40), 9.5881e02, delta=9.5881e-01)

        # SpHt @ T=40degC, X=0.2: 4.3200e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(40), 4.3200e03, delta=4.3200e00)

        # Cond @ T=40degC, X=0.2: 4.8440e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(40), 4.8440e-01, delta=4.8440e-04)

    def test_3(self):

        p = EthylAlcohol(0.4)

        # Visc @ T=5degC, X=0.4: 5.5016e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(5), 5.5016e-03, delta=5.5016e-06)

        # Dens @ T=5degC, X=0.4: 9.4601e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(5), 9.4601e02, delta=9.4601e-01)

        # SpHt @ T=5degC, X=0.4: 3.9315e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(5), 3.9315e03, delta=3.9315e00)

        # Cond @ T=5degC, X=0.4: 3.5458e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(5), 3.5458e-01, delta=3.5458e-04)

        # Visc @ T=20degC, X=0.4: 2.8758e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(20), 2.8758e-03, delta=2.8758e-06)

        # Dens @ T=20degC, X=0.4: 9.3532e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(20), 9.3532e02, delta=9.3532e-01)

        # SpHt @ T=20degC, X=0.4: 4.0293e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(20), 4.0293e03, delta=4.0293e00)

        # Cond @ T=20degC, X=0.4: 3.6120e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(20), 3.6120e-01, delta=3.6120e-04)

        # Visc @ T=40degC, X=0.4: 1.4573e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(40), 1.4573e-03, delta=1.4573e-06)

        # Dens @ T=40degC, X=0.4: 9.2026e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(40), 9.2026e02, delta=9.2026e-01)

        # SpHt @ T=40degC, X=0.4: 4.1199e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(40), 4.1199e03, delta=4.1199e00)

        # Cond @ T=40degC, X=0.4: 3.6934e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(40), 3.6934e-01, delta=3.6934e-04)

    def test_t_freeze(self):
        # T_freeze @ X=0.1: -4.379. ErrTol=0.01C
        self.assertAlmostEqual(EthylAlcohol(0.1).freeze_point(0.1), -4.379, delta=1.0e-02)

        # T_freeze @ X=0.2: -11.119. ErrTol=0.01C
        self.assertAlmostEqual(EthylAlcohol(0.2).freeze_point(0.2), -11.119, delta=1.0e-02)

        # T_freeze @ X=0.3: -20.140. ErrTol=0.01C
        self.assertAlmostEqual(EthylAlcohol(0.3).freeze_point(0.3), -20.140, delta=1.0e-02)

        # T_freeze @ X=0.4: -29.533. ErrTol=0.01C
        self.assertAlmostEqual(EthylAlcohol(0.4).freeze_point(0.4), -29.533, delta=1.0e-02)

        # T_freeze @ X=0.5: -37.611. ErrTol=0.01C
        self.assertAlmostEqual(EthylAlcohol(0.5).freeze_point(0.5), -37.611, delta=1.0e-02)

        # T_freeze @ X=0.6: -44.910. ErrTol=0.01C
        self.assertAlmostEqual(EthylAlcohol(0.6).freeze_point(0.6), -44.910, delta=1.0e-02)



from unittest import TestCase

from scp.ethylene_glycol import EthyleneGlycol


class TestEthyleneGlycol(TestCase):
    def test_1(self):

        p = EthyleneGlycol(0.0)

        # Visc @ T=5degC, X=0: 1.5186e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(5), 1.5186e-03, delta=1.5186e-06)

        # Dens @ T=5degC, X=0: 9.9915e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(5), 9.9915e02, delta=9.9915e-01)

        # SpHt @ T=5degC, X=0: 4.2027e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(5), 4.2027e03, delta=4.2027e00)

        # Cond @ T=5degC, X=0: 5.7137e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(5), 5.7137e-01, delta=5.7137e-04)

        # Visc @ T=20degC, X=0: 1.0078e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(20), 1.0078e-03, delta=1.0078e-06)

        # Dens @ T=20degC, X=0: 9.9735e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(20), 9.9735e02, delta=9.9735e-01)

        # SpHt @ T=20degC, X=0: 4.1862e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(20), 4.1862e03, delta=4.1862e00)

        # Cond @ T=20degC, X=0: 5.9913e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(20), 5.9913e-01, delta=5.9913e-04)

        # Visc @ T=40degC, X=0: 6.5721e-04. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(40), 6.5721e-04, delta=6.5721e-07)

        # Dens @ T=40degC, X=0: 9.9181e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(40), 9.9181e02, delta=9.9181e-01)

        # SpHt @ T=40degC, X=0: 4.1785e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(40), 4.1785e03, delta=4.1785e00)

        # Cond @ T=40degC, X=0: 6.2983e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(40), 6.2983e-01, delta=6.2983e-04)

    def test_2(self):

        p = EthyleneGlycol(0.2)

        # Visc @ T=5degC, X=0.2: 2.6594e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(5), 2.6594e-03, delta=2.6594e-06)

        # Dens @ T=5degC, X=0.2: 1.0281e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(5), 1.0281e03, delta=1.0281e00)

        # SpHt @ T=5degC, X=0.2: 3.8695e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(5), 3.8695e03, delta=3.8695e00)

        # Cond @ T=5degC, X=0.2: 4.9022e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(5), 4.9022e-01, delta=4.9022e-04)

        # Visc @ T=20degC, X=0.2: 1.6624e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(20), 1.6624e-03, delta=1.6624e-06)

        # Dens @ T=20degC, X=0.2: 1.0241e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(20), 1.0241e03, delta=1.0241e00)

        # SpHt @ T=20degC, X=0.2: 3.8962e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(20), 3.8962e03, delta=3.8962e00)

        # Cond @ T=20degC, X=0.2: 5.0766e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(20), 5.0766e-01, delta=5.0766e-04)

        # Visc @ T=40degC, X=0.2: 1.0133e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(40), 1.0133e-03, delta=1.0133e-06)

        # Dens @ T=40degC, X=0.2: 1.0164e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(40), 1.0164e03, delta=1.0164e00)

        # SpHt @ T=40degC, X=0.2: 3.9328e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(40), 3.9328e03, delta=3.9328e00)

        # Cond @ T=40degC, X=0.2: 5.2908e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(40), 5.2908e-01, delta=5.2908e-04)

    def test_3(self):

        p = EthyleneGlycol(0.4)

        # Visc @ T=5degC, X=0.4: 4.7569e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(5), 4.7569e-03, delta=4.7569e-06)

        # Dens @ T=5degC, X=0.4: 1.0585e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(5), 1.0585e03, delta=1.0585e00)

        # SpHt @ T=5degC, X=0.4: 3.4559e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(5), 3.4559e03, delta=3.4559e00)

        # Cond @ T=5degC, X=0.4: 4.1376e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(5), 4.1376e-01, delta=4.1376e-04)

        # Visc @ T=20degC, X=0.4: 2.8191e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(20), 2.8191e-03, delta=2.8191e-06)

        # Dens @ T=20degC, X=0.4: 1.0519e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(20), 1.0519e03, delta=1.0519e00)

        # SpHt @ T=20degC, X=0.4: 3.5190e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(20), 3.5190e03, delta=3.5190e00)

        # Cond @ T=20degC, X=0.4: 4.2530e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(20), 4.2530e-01, delta=4.2530e-04)

        # Visc @ T=40degC, X=0.4: 1.6351e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(40), 1.6351e-03, delta=1.6351e-06)

        # Dens @ T=40degC, X=0.4: 1.0414e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(40), 1.0414e03, delta=1.0414e00)

        # SpHt @ T=40degC, X=0.4: 3.5978e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(40), 3.5978e03, delta=3.5978e00)

        # Cond @ T=40degC, X=0.4: 4.4050e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(40), 4.4050e-01, delta=4.4050e-04)

    def test_t_freeze(self):
        # T_freeze @ X=0.1: -3.357. ErrTol=0.01C
        self.assertAlmostEqual(EthyleneGlycol(0.1).freeze_point(0.1), -3.357, delta=1.0e-02)

        # T_freeze @ X=0.2: -7.949. ErrTol=0.01C
        self.assertAlmostEqual(EthyleneGlycol(0.2).freeze_point(0.2), -7.949, delta=1.0e-02)

        # T_freeze @ X=0.3: -14.576. ErrTol=0.01C
        self.assertAlmostEqual(EthyleneGlycol(0.3).freeze_point(0.3), -14.576, delta=1.0e-02)

        # T_freeze @ X=0.4: -23.813. ErrTol=0.01C
        self.assertAlmostEqual(EthyleneGlycol(0.4).freeze_point(0.4), -23.813, delta=1.0e-02)

        # T_freeze @ X=0.5: -35.994. ErrTol=0.01C
        self.assertAlmostEqual(EthyleneGlycol(0.5).freeze_point(0.5), -35.994, delta=1.0e-02)

        # T_freeze @ X=0.6: -51.201. ErrTol=0.01C
        self.assertAlmostEqual(EthyleneGlycol(0.6).freeze_point(0.6), -51.201, delta=1.0e-02)



from unittest import TestCase

from scp.methyl_alcohol import MethylAlcohol


class TestMethylAlcohol(TestCase):
    def test_1(self):

        p = MethylAlcohol(0.0)

        # Visc @ T=5degC, X=0: 1.5169e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(5), 1.5169e-03, delta=1.5169e-06)

        # Dens @ T=5degC, X=0: 1.0000e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(5), 1.0000e03, delta=1.0000e00)

        # SpHt @ T=5degC, X=0: 4.2159e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(5), 4.2159e03, delta=4.2159e00)

        # Cond @ T=5degC, X=0: 5.7057e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(5), 5.7057e-01, delta=5.7057e-04)

        # Visc @ T=20degC, X=0: 1.0000e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(20), 1.0000e-03, delta=1.0000e-06)

        # Dens @ T=20degC, X=0: 9.9841e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(20), 9.9841e02, delta=9.9841e-01)

        # SpHt @ T=20degC, X=0: 4.1649e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(20), 4.1649e03, delta=4.1649e00)

        # Cond @ T=20degC, X=0: 5.9834e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(20), 5.9834e-01, delta=5.9834e-04)

        # Visc @ T=40degC, X=0: 6.5422e-04. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(40), 6.5422e-04, delta=6.5422e-07)

        # Dens @ T=40degC, X=0: 9.9216e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(40), 9.9216e02, delta=9.9216e-01)

        # SpHt @ T=40degC, X=0: 4.1802e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(40), 4.1802e03, delta=4.1802e00)

        # Cond @ T=40degC, X=0: 6.2986e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(40), 6.2986e-01, delta=6.2986e-04)

    def test_2(self):

        p = MethylAlcohol(0.2)

        # Visc @ T=5degC, X=0.2: 2.6531e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(5), 2.6531e-03, delta=2.6531e-06)

        # Dens @ T=5degC, X=0.2: 9.7135e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(5), 9.7135e02, delta=9.7135e-01)

        # SpHt @ T=5degC, X=0.2: 4.0832e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(5), 4.0832e03, delta=4.0832e00)

        # Cond @ T=5degC, X=0.2: 4.6748e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(5), 4.6748e-01, delta=4.6748e-04)

        # Visc @ T=20degC, X=0.2: 1.5979e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(20), 1.5979e-03, delta=1.5979e-06)

        # Dens @ T=20degC, X=0.2: 9.6679e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(20), 9.6679e02, delta=9.6679e-01)

        # SpHt @ T=20degC, X=0.2: 4.1101e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(20), 4.1101e03, delta=4.1101e00)

        # Cond @ T=20degC, X=0.2: 4.8339e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(20), 4.8339e-01, delta=4.8339e-04)

        # Visc @ T=40degC, X=0.2: 9.4179e-04. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(40), 9.4179e-04, delta=9.4179e-07)

        # Dens @ T=40degC, X=0.2: 9.5837e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(40), 9.5837e02, delta=9.5837e-01)

        # SpHt @ T=40degC, X=0.2: 4.0980e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(40), 4.0980e03, delta=4.0980e00)

        # Cond @ T=40degC, X=0.2: 5.0402e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(40), 5.0402e-01, delta=5.0402e-04)

    def test_3(self):

        p = MethylAlcohol(0.4)

        # Visc @ T=5degC, X=0.4: 3.0165e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(5), 3.0165e-03, delta=3.0165e-06)

        # Dens @ T=5degC, X=0.4: 9.4305e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(5), 9.4305e02, delta=9.4305e-01)

        # SpHt @ T=5degC, X=0.4: 3.7171e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(5), 3.7171e03, delta=3.7171e00)

        # Cond @ T=5degC, X=0.4: 3.7833e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(5), 3.7833e-01, delta=3.7833e-04)

        # Visc @ T=20degC, X=0.4: 1.8385e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(20), 1.8385e-03, delta=1.8385e-06)

        # Dens @ T=20degC, X=0.4: 9.3457e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(20), 9.3457e02, delta=9.3457e-01)

        # SpHt @ T=20degC, X=0.4: 3.8224e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(20), 3.8224e03, delta=3.8224e00)

        # Cond @ T=20degC, X=0.4: 3.8571e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(20), 3.8571e-01, delta=3.8571e-04)

        # Visc @ T=40degC, X=0.4: 1.0684e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(40), 1.0684e-03, delta=1.0684e-06)

        # Dens @ T=40degC, X=0.4: 9.2227e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(40), 9.2227e02, delta=9.2227e-01)

        # SpHt @ T=40degC, X=0.4: 3.8728e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(40), 3.8728e03, delta=3.8728e00)

        # Cond @ T=40degC, X=0.4: 3.9646e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(40), 3.9646e-01, delta=3.9646e-04)

    def test_t_freeze(self):
        # T_freeze @ X=0.1: -6.540. ErrTol=0.01C
        self.assertAlmostEqual(MethylAlcohol(0.1).freeze_point(0.1), -6.540, delta=1.0e-02)

        # T_freeze @ X=0.2: -15.080. ErrTol=0.01C
        self.assertAlmostEqual(MethylAlcohol(0.2).freeze_point(0.2), -15.080, delta=1.0e-02)

        # T_freeze @ X=0.3: -25.685. ErrTol=0.01C
        self.assertAlmostEqual(MethylAlcohol(0.3).freeze_point(0.3), -25.685, delta=1.0e-02)

        # T_freeze @ X=0.4: -38.703. ErrTol=0.01C
        self.assertAlmostEqual(MethylAlcohol(0.4).freeze_point(0.4), -38.703, delta=1.0e-02)

        # T_freeze @ X=0.5: -54.466. ErrTol=0.01C
        self.assertAlmostEqual(MethylAlcohol(0.5).freeze_point(0.5), -54.466, delta=1.0e-02)

        # T_freeze @ X=0.6: -73.006. ErrTol=0.01C
        self.assertAlmostEqual(MethylAlcohol(0.6).freeze_point(0.6), -73.006, delta=1.0e-02)



from unittest import TestCase

from scp.propylene_glycol import PropyleneGlycol


class TestPropyleneGlycol(TestCase):
    def test_1(self):

        p = PropyleneGlycol(0.0)

        # Visc @ T=5degC, X=0: 1.5364e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(5), 1.5364e-03, delta=1.5364e-06)

        # Dens @ T=5degC, X=0: 1.0003e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(5), 1.0003e03, delta=1.0003e00)

        # SpHt @ T=5degC, X=0: 4.2048e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(5), 4.2048e03, delta=4.2048e00)

        # Cond @ T=5degC, X=0: 5.7124e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(5), 5.7124e-01, delta=5.7124e-04)

        # Visc @ T=20degC, X=0: 1.0072e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(20), 1.0072e-03, delta=1.0072e-06)

        # Dens @ T=20degC, X=0: 9.9852e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(20), 9.9852e02, delta=9.9852e-01)

        # SpHt @ T=20degC, X=0: 4.1866e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(20), 4.1866e03, delta=4.1866e00)

        # Cond @ T=20degC, X=0: 5.9913e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(20), 5.9913e-01, delta=5.9913e-04)

        # Visc @ T=40degC, X=0: 6.5033e-04. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(40), 6.5033e-04, delta=6.5033e-07)

        # Dens @ T=40degC, X=0: 9.9253e+02. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(40), 9.9253e02, delta=9.9253e-01)

        # SpHt @ T=40degC, X=0: 4.1783e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(40), 4.1783e03, delta=4.1783e00)

        # Cond @ T=40degC, X=0: 6.3007e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(40), 6.3007e-01, delta=6.3007e-04)

    def test_2(self):

        p = PropyleneGlycol(0.2)

        # Visc @ T=5degC, X=0.2: 3.4941e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(5), 3.4941e-03, delta=3.4941e-06)

        # Dens @ T=5degC, X=0.2: 1.0191e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(5), 1.0191e03, delta=1.0191e00)

        # SpHt @ T=5degC, X=0.2: 3.9459e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(5), 3.9459e03, delta=3.9459e00)

        # Cond @ T=5degC, X=0.2: 4.7647e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(5), 4.7647e-01, delta=4.7647e-04)

        # Visc @ T=20degC, X=0.2: 2.0301e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(20), 2.0301e-03, delta=2.0301e-06)

        # Dens @ T=20degC, X=0.2: 1.0148e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(20), 1.0148e03, delta=1.0148e00)

        # SpHt @ T=20degC, X=0.2: 3.9768e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(20), 3.9768e03, delta=3.9768e00)

        # Cond @ T=20degC, X=0.2: 4.9221e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(20), 4.9221e-01, delta=4.9221e-04)

        # Visc @ T=40degC, X=0.2: 1.1693e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(40), 1.1693e-03, delta=1.1693e-06)

        # Dens @ T=40degC, X=0.2: 1.0064e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(40), 1.0064e03, delta=1.0064e00)

        # SpHt @ T=40degC, X=0.2: 4.0190e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(40), 4.0190e03, delta=4.0190e00)

        # Cond @ T=40degC, X=0.2: 5.1228e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(40), 5.1228e-01, delta=5.1228e-04)

    def test_3(self):

        p = PropyleneGlycol(0.4)

        # Visc @ T=5degC, X=0.4: 8.9817e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(5), 8.9817e-03, delta=8.9817e-06)

        # Dens @ T=5degC, X=0.4: 1.0401e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(5), 1.0401e03, delta=1.0401e00)

        # SpHt @ T=5degC, X=0.4: 3.6580e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(5), 3.6580e03, delta=3.6580e00)

        # Cond @ T=5degC, X=0.4: 3.9089e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(5), 3.9089e-01, delta=3.9089e-04)

        # Visc @ T=20degC, X=0.4: 4.3838e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(20), 4.3838e-03, delta=4.3838e-06)

        # Dens @ T=20degC, X=0.4: 1.0323e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(20), 1.0323e03, delta=1.0323e00)

        # SpHt @ T=20degC, X=0.4: 3.7067e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(20), 3.7067e03, delta=3.7067e00)

        # Cond @ T=20degC, X=0.4: 4.0026e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(20), 4.0026e-01, delta=4.0026e-04)

        # Visc @ T=40degC, X=0.4: 2.1408e-03. Err Tol: 0.1%
        self.assertAlmostEqual(p.viscosity(40), 2.1408e-03, delta=2.1408e-06)

        # Dens @ T=40degC, X=0.4: 1.0201e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.density(40), 1.0201e03, delta=1.0201e00)

        # SpHt @ T=40degC, X=0.4: 3.7708e+03. Err Tol: 0.1%
        self.assertAlmostEqual(p.specific_heat(40), 3.7708e03, delta=3.7708e00)

        # Cond @ T=40degC, X=0.4: 4.1321e-01. Err Tol: 0.1%
        self.assertAlmostEqual(p.conductivity(40), 4.1321e-01, delta=4.1321e-04)

    def test_t_freeze(self):
        # T_freeze @ X=0.1: -2.867. ErrTol=0.01C
        self.assertAlmostEqual(PropyleneGlycol(0.1).freeze_point(0.1), -2.867, delta=1.0e-02)

        # T_freeze @ X=0.2: -7.173. ErrTol=0.01C
        self.assertAlmostEqual(PropyleneGlycol(0.2).freeze_point(0.2), -7.173, delta=1.0e-02)

        # T_freeze @ X=0.3: -12.789. ErrTol=0.01C
        self.assertAlmostEqual(PropyleneGlycol(0.3).freeze_point(0.3), -12.789, delta=1.0e-02)

        # T_freeze @ X=0.4: -20.568. ErrTol=0.01C
        self.assertAlmostEqual(PropyleneGlycol(0.4).freeze_point(0.4), -20.568, delta=1.0e-02)

        # T_freeze @ X=0.5: -32.193. ErrTol=0.01C
        self.assertAlmostEqual(PropyleneGlycol(0.5).freeze_point(0.5), -32.193, delta=1.0e-02)

        # T_freeze @ X=0.6: -50.003. ErrTol=0.01C
        self.assertAlmostEqual(PropyleneGlycol(0.6).freeze_point(0.6), -50.003, delta=1.0e-02)



from unittest import TestCase

from scp.water import Water


class TestWater(TestCase):
    def setUp(self) -> None:
        super().setUp()
        self.p = Water()

    def test_viscosity(self):
        # T: 1 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.viscosity(1.0), 1.731e-03, delta=1.731e-05)

        # T: 5 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.viscosity(5.0), 1.518e-03, delta=1.518e-05)

        # T: 10 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.viscosity(10.0), 1.306e-03, delta=1.306e-05)

        # T: 25 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.viscosity(25.0), 8.900e-04, delta=8.900e-06)

        # T: 50 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.viscosity(50.0), 5.465e-04, delta=5.465e-06)

        # T: 75 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.viscosity(75.0), 3.774e-04, delta=3.774e-06)

        # T: 90 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.viscosity(90.0), 3.142e-04, delta=3.142e-06)

        # T: 95 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.viscosity(95.0), 2.971e-04, delta=2.971e-06)

        # T: 99 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.viscosity(99.0), 2.846e-04, delta=2.846e-06)

    def test_specific_heat(self):
        # T: 1 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.specific_heat(1.0), 4.216e03, delta=4.216e01)

        # T: 5 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.specific_heat(5.0), 4.205e03, delta=4.205e01)

        # T: 10 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.specific_heat(10.0), 4.195e03, delta=4.195e01)

        # T: 25 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.specific_heat(25.0), 4.181e03, delta=4.181e01)

        # T: 50 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.specific_heat(50.0), 4.181e03, delta=4.181e01)

        # T: 75 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.specific_heat(75.0), 4.193e03, delta=4.193e01)

        # T: 90 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.specific_heat(90.0), 4.205e03, delta=4.205e01)

        # T: 95 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.specific_heat(95.0), 4.210e03, delta=4.210e01)

        # T: 99 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.specific_heat(99.0), 4.215e03, delta=4.215e01)

    def test_density(self):
        # T: 1 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.density(1.0), 9.999e02, delta=9.999e00)

        # T: 5 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.density(5.0), 1.000e03, delta=1.000e01)

        # T: 10 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.density(10.0), 9.997e02, delta=9.997e00)

        # T: 25 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.density(25.0), 9.970e02, delta=9.970e00)

        # T: 50 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.density(50.0), 9.880e02, delta=9.880e00)

        # T: 75 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.density(75.0), 9.748e02, delta=9.748e00)

        # T: 90 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.density(90.0), 9.653e02, delta=9.653e00)

        # T: 95 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.density(95.0), 9.619e02, delta=9.619e00)

        # T: 99 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.density(99.0), 9.591e02, delta=9.591e00)

    def test_conductivity(self):
        # T: 1 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.conductivity(1.0), 5.582e-01, delta=5.582e-03)

        # T: 5 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.conductivity(5.0), 5.678e-01, delta=5.678e-03)

        # T: 10 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.conductivity(10.0), 5.788e-01, delta=5.788e-03)

        # T: 25 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.conductivity(25.0), 6.065e-01, delta=6.065e-03)

        # T: 50 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.conductivity(50.0), 6.406e-01, delta=6.406e-03)

        # T: 75 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.conductivity(75.0), 6.636e-01, delta=6.636e-03)

        # T: 90 [C], ErrTol: 1.0%
        # PropsSI('L', 'P', 101325, 'T', 273.15 + 90, 'WATER')
        self.assertAlmostEqual(self.p.conductivity(90.0), 6.728e-01, delta=6.728e-03)

        # T: 95 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.conductivity(95.0), 6.752e-01, delta=6.752e-03)

        # T: 99 [C], ErrTol: 1.0%
        self.assertAlmostEqual(self.p.conductivity(99.0), 6.768e-01, delta=6.768e-03)

    def test_t_freeze(self):
        self.assertAlmostEqual(Water().freeze_point(), 0.000, delta=1.0e-02)



import pathlib

from setuptools import setup

from scp import VERSION

readme_file = pathlib.Path(__file__).parent.resolve() / 'README.md'
readme_contents = readme_file.read_text()

setup(
    name="SecondaryCoolantProps",
    version=VERSION,
    packages=['scp'],
    description="A collection of secondary coolant fluid property functions and classes",
    install_requires=['click'],
    long_description=readme_contents,
    long_description_content_type='text/markdown',
    author='Matt Mitchell',
    author_email='mitchute@gmail.com',
    url='https://github.com/mitchute/SecondaryCoolantProps',
    license='BSD license',
    entry_points={
        'console_scripts': ['scprop=scp.cli:cli']
    }
)
